﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using MbUnit.Framework;
using TypeMock;

namespace TestingLinqToSQLTypeMock.Tests
{
    [TestFixture]
    [ClearMocks]
    public class ProductControllerTests
    {
        [Test]
        [VerifyMocks]
        public void MockDataContext()
        {
            Category category = new Category();
            category.id = 1;
            category.Title = "Test";
            category.Description = "Testing";

            List<Category> dummyData = new List<Category> { category };
            using (RecordExpectations r = RecorderManager.StartRecording())
            {
                // Mock Linq
                List<Category> mocked = ProductController.GetCategories();
                // return fake results
                r.Return(dummyData);
            }

            List<Category> categories = ProductController.GetCategories();
            Assert.AreEqual(1, categories.Count);
            Assert.AreEqual("Test", categories[0].Title);
            Assert.AreEqual("Testing", categories[0].Description);
        }

        public class Customer
        {
            public int Id { get; set; }
            public string Name { get; set; }
            public string City { get; set; }
        }

        [Test]
        [VerifyMocks]
        public void MockList()
        {
            List<Customer> m_CustomerList = new List<Customer> {
                new Customer{ Id = 1, Name="Dave", City="Sarasota" },
                new Customer{ Id = 2, Name="John", City="Tampa" },
                new Customer{ Id = 3, Name="Abe", City="Miami" }
            };

            var dummyData = new[] {new {Name="fake",City="typemock"},
                       new {Name="another",City="typemock"}};
            using (RecordExpectations recorder = RecorderManager.StartRecording())
            {
                // Mock Linq
                var queryResult = from c in m_CustomerList
                                  where c.City == "Sarasota"
                                  select new { c.Name, c.City };
                // return fake results
                recorder.Return(dummyData);
            }

            var actual =  from c in m_CustomerList
                          where c.City == "Sarasota"
                          select new { c.Name, c.City };
            
            Assert.AreEqual(2, actual.Count());
        }
    }


}
